biom.table.Table._data_equality — biom-format.org

# biom-format.org

## biom.table.Table._data_equality

`Table.` `_data_equality`(other)

  Return `True` if both matrices are equal.

  Matrices are equal iff the following items are equal: - shape - dtype - size (nnz) - matrix data (more expensive, so checked last)

  The sparse format does not need to be the same between the two matrices. `self` and `other` will be converted to csr format if necessary before performing the final comparison.